:orphan:

Contributing to MNE-BIDS
========================

MNE-BIDS is an open-source software project developed through community effort.
You are very welcome to participate in the development by reporting bugs,
writing documentation, or contributing code.

Development takes place on the collaborative platform GitHub at
`github.com/mne-tools/mne-bids <https://github.com/mne-tools/mne-bids>`_.

.. image:: https://mne.tools/mne-bids/assets/GitHub.png
   :width: 400
   :alt: GitHub Logo
   :target: https://github.com/mne-tools/mne-bids


Bug reports
-----------

Use the `GitHub issue tracker <https://github.com/mne-tools/mne-bids/issues>`_
to report bugs.

Contributing code or documentation
----------------------------------

Please see our `contributing guide <https://github.com/mne-tools/mne-bids/blob/main/CONTRIBUTING.md>`_
to find out how to get started.
